@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2024 Maxime DOYEN
+ *  Copyright (C) 1995-2025 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -20,6 +20,8 @@
 
 #include "homebank.h"
 
+#include "ui-dialogs.h"
+#include "ui-widgets.h"
 #include "hbtk-switcher.h"
 #include "ui-category.h"
 
@@ -426,15 +428,15 @@ GtkEntryCompletion *completion;
 	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET(mainbox)), GTK_STYLE_CLASS_LINKED);
 	
 	entry = gtk_entry_new();
-	gtk_box_pack_start(GTK_BOX(mainbox), entry, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX(mainbox), entry);
 
 	menubutton = gtk_menu_button_new ();
 	//data->MB_template = menubutton;
-	image = gtk_image_new_from_icon_name ("pan-down-symbolic", GTK_ICON_SIZE_BUTTON);
+	image = hbtk_image_new_from_icon_name_16 ("pan-down-symbolic");
 	gtk_button_set_image(GTK_BUTTON(menubutton), image);
 	gtk_menu_button_set_direction (GTK_MENU_BUTTON(menubutton), GTK_ARROW_LEFT );
 	//gtk_widget_set_halign (menubutton, GTK_ALIGN_END);
-	gtk_box_pack_start(GTK_BOX(mainbox), menubutton, FALSE, FALSE, 0);
+	gtk_box_prepend(GTK_BOX(mainbox), menubutton);
 	
     completion = gtk_entry_completion_new ();
 
@@ -461,7 +463,7 @@ GtkEntryCompletion *completion;
 
 	box = gtk_box_new(GTK_ORIENTATION_VERTICAL, SPACING_MEDIUM);
 	scrollwin = make_scrolled_window(GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	gtk_box_pack_start(GTK_BOX(box), scrollwin, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX(box), scrollwin);
 	//gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scrollwin), HB_MINHEIGHT_LIST);
 	treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(store));
 	gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), treeview);
@@ -1708,8 +1710,7 @@ gint row, n_child;
 		gtk_grid_set_row_spacing (GTK_GRID (grid), SPACING_SMALL);
 		gtk_grid_set_column_spacing (GTK_GRID (grid), SPACING_MEDIUM);
 		hb_widget_set_margin(GTK_WIDGET(grid), SPACING_LARGE);
-		gtk_box_pack_start (GTK_BOX (content_area), grid, TRUE, TRUE, 0);
-
+		hbtk_box_prepend (GTK_BOX (content_area), grid);
 
 		// group :: General
 		row = 0;
@@ -1872,7 +1873,7 @@ GtkTreeIter iter;
 
 		content = gtk_message_dialog_get_message_area(GTK_MESSAGE_DIALOG (dialog));
 		mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
-		gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
+		hbtk_box_prepend (GTK_BOX (content), mainvbox);
 
 		secondtext = _("Transactions assigned to this category,\n"
 			  "will be moved to the category selected below.");
@@ -1882,10 +1883,10 @@ GtkTreeIter iter;
 
 		//getwidget = ui_cat_comboboxentry_new(NULL);
 		getwidget = ui_cat_entry_popover_new(NULL);
-		gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (mainvbox), getwidget);
 
 		cb_subcat = gtk_check_button_new_with_mnemonic(_("Include _subcategories"));
-		gtk_box_pack_start (GTK_BOX (mainvbox), cb_subcat, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (mainvbox), cb_subcat);
 
 		//#2079801 warn budget
 		secondtext = g_strdup_printf (
@@ -1893,7 +1894,7 @@ GtkTreeIter iter;
 		togglebutton = gtk_check_button_new_with_mnemonic(secondtext);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(togglebutton), TRUE);
 		g_free(secondtext);
-		gtk_box_pack_start (GTK_BOX (mainvbox), togglebutton, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (mainvbox), togglebutton);
 
 		//setup 
 		//gtk_combo_box_set_active(GTK_COMBO_BOX(getwidget), oldpos);
@@ -2419,14 +2420,14 @@ gint w, h, dw, dh, row;
 	//dialog contents
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX (content), mainvbox);
 	hb_widget_set_margin(GTK_WIDGET(mainvbox), SPACING_LARGE);
 
     //our table
 	table = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (table), SPACING_SMALL);
 	gtk_grid_set_column_spacing (GTK_GRID (table), SPACING_MEDIUM);
-	gtk_box_pack_start (GTK_BOX (mainvbox), table, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX (mainvbox), table);
 
 	//filter part
 	row = 0;
@@ -2435,24 +2436,24 @@ gint w, h, dw, dh, row;
 	
 	widget = make_image_toggle_button(ICONNAME_HB_BUTTON_HIDE, _("Show Hidden") );
 	data->BT_showhidden = widget;
-	gtk_box_pack_start(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (bbox), widget);
 
 	widget = make_image_toggle_button(ICONNAME_HB_BUTTON_USAGE, _("Show Usage") );
 	data->BT_showusage = widget;
-	gtk_box_pack_start(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (bbox), widget);
 	
 	widget = hbtk_switcher_new (GTK_ORIENTATION_HORIZONTAL);
 	hbtk_switcher_setup(HBTK_SWITCHER(widget), CYA_CAT_TYPE, TRUE);
 	data->RA_type = widget;
 	//gtk_widget_set_halign (bbox, GTK_ALIGN_CENTER);
-	gtk_box_pack_start(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (bbox), widget);
 
 	//menubutton
 	widget = gtk_menu_button_new();
-	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
+	image = hbtk_image_new_from_icon_name_16 (ICONNAME_HB_BUTTON_MENU);
 	g_object_set (widget, "image", image,  NULL);
 	gtk_widget_set_halign (widget, GTK_ALIGN_END);
-	gtk_box_pack_end(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	gtk_box_append (GTK_BOX (bbox), widget);
 
 	GMenu *menu = g_menu_new ();
 	GMenu *section = g_menu_new ();
@@ -2476,7 +2477,7 @@ gint w, h, dw, dh, row;
 	
 	widget = make_search();
 	data->ST_search = widget;
-	gtk_box_pack_end(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	gtk_box_append(GTK_BOX (bbox), widget);
 
 
 	// list + toolbar
@@ -2491,52 +2492,52 @@ gint w, h, dw, dh, row;
 	gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scrollwin), treeview);
 	gtk_widget_set_hexpand (scrollwin, TRUE);
 	gtk_widget_set_vexpand (scrollwin, TRUE);
-	gtk_box_pack_start (GTK_BOX(vbox), scrollwin, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX(vbox), scrollwin);
 
 	//list toolbar
 	tbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
 	gtk_style_context_add_class (gtk_widget_get_style_context (tbar), GTK_STYLE_CLASS_INLINE_TOOLBAR);
-	gtk_box_pack_start (GTK_BOX (vbox), tbar, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (vbox), tbar);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (tbar), bbox);
 
 		widget = make_image_toggle_button(ICONNAME_LIST_ADD, _("Add"));
 		data->BT_add = widget;
-		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend(GTK_BOX(bbox), widget);
 
 		widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
 		data->BT_delete = widget;
-		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend(GTK_BOX(bbox), widget);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (tbar), bbox);
 
 		widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
 		data->BT_edit = widget;
-		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend(GTK_BOX(bbox), widget);
 
 		widget = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
 		data->BT_merge = widget;
-		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend(GTK_BOX(bbox), widget);
 
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_start (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (tbar), bbox);
 
 		widget = make_image_button(ICONNAME_HB_BUTTON_HIDE, _("Show/Hide"));
 		data->BT_hide = widget;
-		gtk_box_pack_start(GTK_BOX(bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend(GTK_BOX(bbox), widget);
 	
 	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-	gtk_box_pack_end (GTK_BOX (tbar), bbox, FALSE, FALSE, 0);
+	gtk_box_append (GTK_BOX (tbar), bbox);
 	
 		widget = make_image_button(ICONNAME_HB_BUTTON_EXPAND, _("Expand all"));
 		data->BT_expand = widget;
-		gtk_box_pack_start (GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (bbox), widget);
 
 		widget = make_image_button(ICONNAME_HB_BUTTON_COLLAPSE, _("Collapse all"));
 		data->BT_collapse = widget;
-		gtk_box_pack_start (GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+		gtk_box_prepend (GTK_BOX (bbox), widget);
 
 	// subcategory + add button
 	row++;
@@ -2549,22 +2550,21 @@ gint w, h, dw, dh, row;
 	widget = gtk_entry_new ();
 	data->ST_name1 = widget;
 	gtk_entry_set_placeholder_text(GTK_ENTRY(data->ST_name1), _("new category") );
-	gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX (vbox), widget);
 	
 	row++;
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
-	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (vbox), hbox);
 	data->LA_category = gtk_label_new(NULL);
-	gtk_box_pack_start (GTK_BOX (hbox), data->LA_category, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (hbox), data->LA_category);
 	label = gtk_label_new(":");
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_box_prepend (GTK_BOX (hbox), label);
 	data->ST_name2 = gtk_entry_new ();
 	gtk_entry_set_placeholder_text(GTK_ENTRY(data->ST_name2), _("new subcategory") );
-	gtk_box_pack_start (GTK_BOX (hbox), data->ST_name2, TRUE, TRUE, 0);
+	hbtk_box_prepend (GTK_BOX (hbox), data->ST_name2);
 
 
 	// connect dialog signals
-    g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
 	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_cat_manage_mapped), &dialog);
 	g_signal_connect (dialog, "key-press-event", G_CALLBACK (ui_cat_manage_dialog_cb_on_key_press), (gpointer)data);
 
